log() {
	logger -t odroid-base-installer "$@"
}

error() {
	log "error: $*"
}

warning() {
	log "warning: $*"
}

info() {
	log "info: $*"
}

exit_error() {
	error "exiting on error $1"
	db_progress stop
	db_input critical $1 || [ $? -eq 30 ]
	db_go
	exit 1
}

odroid_model_long() {
	if [ -e /etc/flash-kernel/machine ]; then
		cat /etc/flash-kernel/machine
	elif [ -e /proc/device-tree/model ]; then
		cat /proc/device-tree/model
	elif [ -e /sys/firmware/devicetree/base/model ]; then
		cat /sys/firmware/devicetree/base/model
	elif [ -e /sys/devices/soc0/machine ]; then
		cat /sys/devices/soc0/machine
	fi
}

odroid_model_simple() {
	case $(odroid_model_long) in
		"Hardkernel ODROID-C2")
			echo "odroidc2"
			;;
		"Hardkernel ODROID-C4")
			echo "odroidc4"
			;;
		"Hardkernel ODROID-HC4")
			echo "odroidhc4"
			;;
		"Hardkernel ODROID-GO2")
			echo "odroidgo2"
			;;
		"Hardkernel ODROID-M1")
			echo "odroidm1"
			;;
		"Hardkernel ODROID-M1S")
			echo "odroidm1s"
			;;
		"Hardkernel ODROID-N2")
			echo "odroidn2"
			;;
		"Hardkernel ODROID-N2L")
			echo "odroidn2l"
			;;
		"Hardkernel ODROID-N2Plus")
			echo "odroidn2_plus"
			;;
		"Hardkernel Odroid-XU4")
			echo "odroidxu3"
			;;
	esac
}

default_bootscript_package() {
	local model=$(odroid_model_simple)

	case "$model" in
		odroidxu3)
			echo "bootscript-odroid-exynos5422"
			;;
		odroidm1 | odroidm1s)
			echo "bootscript-odroidm1"
			;;
		odroidn2*)
			echo "bootscript-odroidn2"
			;;
		odroidc4 | odroidhc4)
			echo "bootscript-odroidc4"
			;;
		*)
			echo "bootscript-$model"
			;;
	esac
}

default_uboot_package() {
	local model=$(odroid_model_simple)

	case "$model" in
		odroidxu3)
			echo "u-boot-odroidxu3"
			;;
		odroidn2l*)
			echo "u-boot-odroidn2l"
			;;
		odroidn2*)
			echo "u-boot-odroidn2"
			;;
		odroidc4 | odroidhc4)
			echo "u-boot-odroidc4"
			;;
		*)
			echo "u-boot-$model"
			;;
	esac
}
